<?php
/**
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly


if( !class_exists( 'seanlite_customize' ) ) {

	class seanlite_customize {

		public $theme_fields;

		public function __construct( $fields = array() ) {

			$this->theme_fields = $fields;

			add_action ('admin_init' , array( &$this, 'admin_scripts' ) );
			add_action ('customize_register' , array( &$this, 'customize_panel' ) );
			add_action ('customize_controls_enqueue_scripts' , array( &$this, 'customize_scripts' ) );

		}

		public function admin_scripts() {

			global $wp_version, $pagenow;

			$file_dir = get_template_directory_uri()."/core/admin/assets/";

			if ( $pagenow == 'post.php' || $pagenow == 'post-new.php' || $pagenow == 'edit.php' ) {

				wp_enqueue_style( 'sean-lite-style', $file_dir.'css/theme.css' );
				wp_enqueue_script( 'sean-lite-script', $file_dir.'js/theme.js',array('jquery'),'',TRUE );
				wp_enqueue_script( "jquery-ui-core", array('jquery'));
				wp_enqueue_script( "jquery-ui-tabs", array('jquery'));

			}

		}

		public function customize_scripts() {

			wp_enqueue_style (
				'wip_panel',
				get_template_directory_uri() . '/core/admin/assets/css/customize.css',
				array(),
				''
			);

	   }

	   public function customize_panel ( $wp_customize ) {

			$theme_panel = $this->theme_fields ;

			foreach ( $theme_panel as $element ) {

				switch ( $element['type'] ) {

					case 'panel' :

						$wp_customize->add_panel( $element['id'], array(

							'title' => $element['title'],
							'priority' => $element['priority'],
							'description' => $element['description'],
							'capability'     => 'edit_theme_options',

						) );

					break;

					case 'section' :

						$wp_customize->add_section( $element['id'], array(

							'title' => $element['title'],
							'panel' => $element['panel'],
							'priority' => $element['priority'],
							'capability'     => 'edit_theme_options',

						) );

					break;

					case 'text' :

						$wp_customize->add_setting( $element['id'], array(

							'sanitize_callback' => 'sanitize_text_field',
							'default' => $element['std'],
							'capability'     => 'edit_theme_options',

						) );

						$wp_customize->add_control( $element['id'] , array(

							'type' => $element['type'],
							'section' => $element['section'],
							'label' => $element['label'],
							'description' => $element['description'],

						) );

					break;

					case 'upload' :

						$wp_customize->add_setting( $element['id'], array(

							'default' => $element['std'],
							'capability' => 'edit_theme_options',
							'sanitize_callback' => 'esc_url_raw'

						) );

						$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, $element['id'], array(

							'label' => $element['label'],
							'description' => $element['description'],
							'section' => $element['section'],
							'settings' => $element['id'],

						)));

					break;

					case 'url' :

						$wp_customize->add_setting( $element['id'], array(

							'sanitize_callback' => 'esc_url_raw',
							'default' => $element['std'],
							'capability'     => 'edit_theme_options',

						) );

						$wp_customize->add_control( $element['id'] , array(

							'type' => $element['type'],
							'section' => $element['section'],
							'label' => $element['label'],
							'description' => $element['description'],

						) );

					break;

					case 'button' :

						$wp_customize->add_setting( $element['id'], array(

							'sanitize_callback' => array( &$this, 'customize_button_sanize' ),
							'default' => $element['std'],
							'capability'     => 'edit_theme_options',

						) );

						$wp_customize->add_control( $element['id'] , array(

							'type' => 'url',
							'section' => $element['section'],
							'label' => $element['label'],
							'description' => $element['description'],

						) );

					break;

					case 'textarea' :

						$wp_customize->add_setting( $element['id'], array(

							'sanitize_callback' => 'esc_textarea',
							'default' => $element['std'],
							'capability'     => 'edit_theme_options',

						) );


						$wp_customize->add_control( $element['id'] , array(

							'type' => $element['type'],
							'section' => $element['section'],
							'label' => $element['label'],
							'description' => $element['description'],

						) );

					break;

					case 'custom_css' :

						$wp_customize->add_setting( $element['id'], array(

							'default' => $element['std'],
							'sanitize_callback'    => 'wp_filter_nohtml_kses',
							'sanitize_js_callback' => 'wp_filter_nohtml_kses',
							'capability'     => 'edit_theme_options',

						) );


						$wp_customize->add_control( $element['id'] , array(

							'type' => 'textarea',
							'section' => $element['section'],
							'label' => $element['label'],
							'description' => $element['description'],

						) );

					break;

					case 'select' :

						$wp_customize->add_setting( $element['id'], array(

							'sanitize_callback' => array( &$this, 'customize_select_sanize' ),
							'default' => $element['std'],
							'capability'     => 'edit_theme_options',

						) );


						$wp_customize->add_control( $element['id'] , array(

							'type' => $element['type'],
							'section' => $element['section'],
							'label' => $element['label'],
							'description' => $element['description'],
							'choices'  => $element['options'],

						) );

					break;

					case 'sean-lite-customize-info' :

						$wp_customize->add_section( $element['id'], array(

							'title' => $element['title'],
							'priority' => $element['priority'],
							'capability' => 'edit_theme_options',

						));

						$wp_customize->add_setting(  $element['id'], array(
							'sanitize_callback' => 'esc_url_raw'
						));

						$wp_customize->add_control( new Seanlite_Customize_Info_Control( $wp_customize,  $element['id'] , array(
							'section' => $element['section'],
						)));

					break;

				}

			}

	   }

		public function customize_select_sanize ( $value, $setting ) {

			$theme_panel = $this->theme_fields ;

			foreach ( $theme_panel as $element ) {

				if ( $element['id'] == $setting->id ) :

					if ( array_key_exists($value, $element['options'] ) ) :

						return $value;

					endif;

				endif;

			}

		}

		public function customize_button_sanize ( $value, $setting ) {

			$sanize = array (

				'wip_footer_email_button' => 'mailto:',
				'wip_footer_skype_button' => 'skype:',
				'wip_footer_whatsapp_button' => 'tel:',

			);

			if ( !strstr ( $value, $sanize[$setting->id]) ) :

				return $sanize[$setting->id] . $value;

			else:

				return esc_url_raw($value, array('skype', 'tel', 'mailto'));

			endif;

		}

	}

}

if ( class_exists( 'WP_Customize_Control' ) ) {

	class SeanLite_Customize_Info_Control extends WP_Customize_Control {

		public $type = "sean-lite-customize-info";

		public function render_content() { ?>

            <div class="inside">

                <h2><?php esc_html_e('Pay what you want','sean-lite');?></h2>
                
                <p><?php esc_html_e('You have the freedom to set your own price for purchasing the Sean theme and receive an additional bundle of 13 WordPress products.','sean-lite');?></p>
                <em><?php esc_html_e('(Minimum price allowed €1)','sean-lite');?></em>

                <h2><?php esc_html_e('Pro features of Sean','sean-lite');?></h2>

                <ul class="features-list">

                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('8 blog layouts','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Custom copyright text on footer','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Choose custom colors','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('WooCommerce Support','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Masonry layout','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Portfolio section','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Display a slideshow for gallery posts','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Testimonials section','sean-lite');?></li>
                    <li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Unlimited sidebars','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Custom shortcodes','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Shortcodes generator','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Backup section','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Sample data','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('Unlimited website usage','sean-lite');?></li>
                	<li><span class="dashicon dashicons dashicons-yes"></span><?php esc_html_e('30 days money back guarantee','sean-lite');?></li>

                </ul>

                <ul>
                
                    <li><a class="button demo-button" href="<?php echo esc_url( 'https://demo.themeinprogress.com/?theme=Sean' ); ?>" title="<?php esc_attr_e('View live demo','sean-lite');?>" target="_blank"><?php esc_html_e('View live demo','sean-lite');?></a></li>
                    <li><a class="button purchase-button" href="<?php echo esc_url( 'https://www.themeinprogress.com/sean-free-creative-portfolio-wordpress-theme/?ref=panel' ); ?>" title="<?php esc_attr_e('Name your price','sean-lite');?>" target="_blank"><?php esc_html_e('Name your price','sean-lite');?></a></li>
                
                </ul>

            </div>

            <div class="inside">

                <h2><?php esc_html_e('Become a supporter','sean-lite');?></h2>
                <p><?php esc_html_e("If you like this theme and support, I'd appreciate any of the following:","sean-lite");?></p>

                <ul>

                    <li><a class="button" href="<?php echo esc_url( 'https://wordpress.org/support/view/theme-reviews/'.get_stylesheet().'#postform' ); ?>" title="<?php esc_attr_e('Rate this Theme','sean-lite');?>" target="_blank"><?php esc_html_e('Rate this Theme','sean-lite');?></a></li>
                    <li><a class="button" href="<?php echo esc_url( 'https://www.themeinprogress.com/reserved-area/' ); ?>" title="<?php esc_attr_e('Subscribe our newsletter','sean-lite');?>" target="_blank"><?php esc_html_e('Subscribe our newsletter','sean-lite');?></a></li>

                </ul>

            </div>

		<?php

		}

	}

}

?>
