<?php

/**
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * It is also available at this URL: http://www.gnu.org/licenses/gpl-3.0.txt
 */

define( 'SEAN_LITE_MIN_PHP_VERSION', '5.3' );

/*-----------------------------------------------------------------------------------*/
/* Switches back to the previous theme if the minimum PHP version is not met */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'sean_lite_check_php_version' ) ) {

	function sean_lite_check_php_version() {
	
		if ( version_compare( PHP_VERSION, SEAN_LITE_MIN_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', 'sean_lite_min_php_not_met_notice' );
			switch_theme( get_option( 'theme_switched' ));
			return false;
	
		};
	}

	add_action( 'after_switch_theme', 'sean_lite_check_php_version' );

}

/*-----------------------------------------------------------------------------------*/
/* An error notice that can be displayed if the Minimum PHP version is not met */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'sean_lite_min_php_not_met_notice' ) ) {

	function sean_lite_min_php_not_met_notice() {
		?>
		<div class="notice notice-error is_dismissable">
			<p>
				<?php esc_html_e('You need to update your PHP version to run this theme.', 'sean-lite' ); ?><br />
				<?php
				printf(
					esc_html__( 'Actual version is: %1$s, required version is: %2$s.', 'sean-lite' ),
					PHP_VERSION,
					SEAN_LITE_MIN_PHP_VERSION
				);
				?>
			</p>
		</div>
		<?php
	
	}
	
}

/*-----------------------------------------------------------------------------------*/
/* POST CLASS */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('seanlite_post_class')) {

	function seanlite_post_class($classes) {
	
		$classes[] = 'post-container col-md-12';
			
		return $classes;
		
	}
	
	add_filter('post_class', 'seanlite_post_class');

}

/*-----------------------------------------------------------------------------------*/
/* REQUEST FUNCTION */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('seanlite_request')) {

	function seanlite_request($id) {
		
		if ( isset ( $_REQUEST[$id])) 
		return $_REQUEST[$id];	
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* THEME PATH */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('seanlite_theme_data')) {

	function seanlite_theme_data($id) {
		
		$themedata = wp_get_theme();
		return $themedata->get($id);
		
	}
	
}

/*-----------------------------------------------------------------------------------*/
/* THEME SETTINGS */
/*-----------------------------------------------------------------------------------*/ 


if (!function_exists('seanlite_setting')) {
	
	function seanlite_setting($id) {
		
		$seanlite_setting = get_theme_mod($id);
			
		if(isset($seanlite_setting))
			return $seanlite_setting;
		
	}
	
}

/*-----------------------------------------------------------------------------------*/
/* POST META */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'seanlite_postmeta' ) ) {

	function seanlite_postmeta($id) {
	
		global $post;
		
		if (!is_404()) {
			$val = get_post_meta( $post->ID , $id, TRUE);
			if(isset($val))
			return $val;
		} else {
			return null;
		}
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* POST ICON */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'seanlite_posticon' ) ) {

	function seanlite_posticon() {
	
		$icons = array (
			
			"video" => "genericon-video" , 
			"gallery" => "genericon-image" , 
			"audio" => "genericon-audio" , 
			"chat" => "genericon-chat", 
			"status" => "genericon-status", 
			"image" => "genericon-picture", 
			"quote" => "genericon-quote" , 
			"link" => "genericon-external", 
			"aside" => "genericon-aside"
			
		);
	
		if (get_post_format()) { 
			
			$icon = '<span class="genericon ' . esc_attr($icons[get_post_format()]) . '"></span> '. esc_html(ucfirst(get_post_format())); 
		
		} else {
			
			$icon = '<span class="genericon genericon-standard"></span> ' . esc_html__('Standard','sean-lite'); 
		
		}
		
		return $icon;
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* Infinitescroll system */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'seanlite_infinitescroll_class' ) ) {

	function seanlite_infinitescroll_class($classes) {
		
		if ( seanlite_setting('wip_infinitescroll_system') == "on" ) :
		
			$classes[] = 'infinitescroll';
				
		endif;
	
		return $classes;
	
	}
	
	add_filter('body_class','seanlite_infinitescroll_class');

}

/*-----------------------------------------------------------------------------------*/
/* Body class */
/*-----------------------------------------------------------------------------------*/   

function seanlite_body_class($classes) {

	$classes[] = 'custombody';
		
	return $classes;
	
}

add_filter('body_class', 'seanlite_body_class');

/*-----------------------------------------------------------------------------------*/
/* Content template */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'seanlite_template' ) ) {

	function seanlite_template($id) {
	
		$template = array ("full" => "col-md-12" , "left-sidebar" => "col-md-8" , "right-sidebar" => "col-md-8" );
	
		$span = $template["right-sidebar"];
		$sidebar =  "right-sidebar";
	
		if  ( ( (is_category()) || (is_tag()) || (is_tax()) || (is_month() ) ) && (seanlite_setting('wip_category_layout')) ) {
			
			$span = $template[esc_attr(seanlite_setting('wip_category_layout'))];
			$sidebar =  esc_attr(seanlite_setting('wip_category_layout'));
				
		} else if ( (is_home()) && (seanlite_setting('wip_home')) ) {
			
			$span = $template[esc_attr(seanlite_setting('wip_home'))];
			$sidebar =  esc_attr(seanlite_setting('wip_home'));
			
		} else if ( (is_search()) && (seanlite_setting('wip_search_layout')) ) {
			
			$span = $template[esc_attr(seanlite_setting('wip_search_layout'))];
			$sidebar =  esc_attr(seanlite_setting('wip_search_layout'));
			
		} else if ( ( (is_single()) || (is_page()) ) && (seanlite_postmeta('wip_template')) ) {
			
			$span = $template[esc_attr(seanlite_postmeta('wip_template'))];
			$sidebar =  esc_attr(seanlite_postmeta('wip_template'));
				
		}
	
		return ${$id};
		
	}

}

/*-----------------------------------------------------------------------------------*/
/*RESPONSIVE EMBED */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'seanlite_get_thumbs' ) ) {
	
	function seanlite_embed_html( $html ) {
		return '<div class="embed-container">' . $html . '</div>';
	}
	 
	add_filter( 'embed_oembed_html', 'seanlite_embed_html', 10, 3 );
	add_filter( 'video_embed_html', 'seanlite_embed_html' );
	
}

/*-----------------------------------------------------------------------------------*/
/* IS SINGLE */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('seanlite_is_single')) {

	function seanlite_is_single() {
		
		if ( is_single() || is_page() ) :
		
			return true;
		
		endif;
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* THUMBNAILS */
/*-----------------------------------------------------------------------------------*/         

if ( ! function_exists( 'seanlite_get_thumbs' ) ) {
	
	function seanlite_get_thumbs($type) {
		
		if (seanlite_setting('wip_'.$type.'_thumbinal')):
			return seanlite_setting('wip_'.$type.'_thumbinal');
		else:
			return "550";
		endif;
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* GET PAGED */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'seanlite_paged' ) ) {

	function seanlite_paged() {
		
		if ( get_query_var('paged') ) {
			$paged = get_query_var('paged');
		} elseif ( get_query_var('page') ) {
			$paged = get_query_var('page');
		} else {
			$paged = 1;
		}
		
		return $paged;
		
	}

}

/*-----------------------------------------------------------------------------------*/
/* PRETTYPHOTO */
/*-----------------------------------------------------------------------------------*/   

if ( ! function_exists( 'seanlite_prettyPhoto' ) ) {

	function seanlite_prettyPhoto( $html, $id, $size, $permalink, $icon, $text ) {
		
		if ( ! $permalink )
			return str_replace( '<a', '<a rel="prettyPhoto" ', $html );
		else
			return $html;
	}
	
	add_filter( 'wp_get_attachment_link', 'seanlite_prettyPhoto', 10, 6);

}

/*-----------------------------------------------------------------------------------*/
/* EXCERPT MORE  */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('seanlite_hide_excerpt_more')) {

	function seanlite_hide_excerpt_more() {
		return '';
	}
	
	add_filter('the_content_more_link', 'seanlite_hide_excerpt_more');
	add_filter('excerpt_more', 'seanlite_hide_excerpt_more');

}

/*-----------------------------------------------------------------------------------*/
/* Customize excerpt more */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('seanlite_customize_excerpt_more')) {

	function seanlite_customize_excerpt_more( $excerpt ) {

		global $post;

		if ( seanlite_is_single() ) :

			return $excerpt;

		else:

			$allowed = array(
				'span' => array(
					'class' => array(),
				),
			);

			$class = 'more';
			$button = ' [...] ';
	
			if ( seanlite_setting('wip_readmore_button') == "on" ) : 
			
				$class = 'button';
				$button = esc_html__('Read more',"sean-lite");
	
			endif;

			if ( 
				( $pos=strpos($post->post_content, '<!--more-->') ) && 
				!has_excerpt($post->ID)
			): 
			
				$content = apply_filters( 'the_content', get_the_content());
			else:
			
				$content = $excerpt;
	
			endif;
	
			return $content. '<a class="'. wp_kses($class, $allowed) . '" href="' . esc_url(get_permalink($post->ID)) . '" title="'.esc_attr__('Read More','sean-lite').'">' . $button . '</a>';

		endif;
		

	}
	
	add_filter( 'get_the_excerpt', 'seanlite_customize_excerpt_more' );

}

/*-----------------------------------------------------------------------------------*/
/* REMOVE CATEGORY LIST REL */
/*-----------------------------------------------------------------------------------*/   

if ( ! function_exists( 'seanlite_remove_cat_rel' ) ) {

	function seanlite_remove_cat_rel($output) {
	
		$output = str_replace('rel="category"', '', $output);
		return $output;
	
	}
	
	add_filter('wp_list_categories', 'seanlite_remove_cat_rel');
	add_filter('the_category', 'seanlite_remove_cat_rel');

}

/*-----------------------------------------------------------------------------------*/
/* REMOVE THUMBNAIL DIMENSION */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'seanlite_thumbs_size' ) ) {

	function seanlite_thumbs_size( $html, $post_id, $post_image_id ) {
		
		$html = preg_replace( '/(width|height)=\"\d*\"\s/', "", $html );
		return $html;
	
	}
	
	add_filter( 'post_thumbnail_html', 'seanlite_thumbs_size', 10, 3 );
  
}

/*-----------------------------------------------------------------------------------*/
/* REMOVE CSS GALLERY */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'seanlite_gallery_style' ) ) {

	function seanlite_gallery_style() {
		return "<div class='gallery'>";
	}
	
	add_filter( 'gallery_style', 'seanlite_gallery_style', 99 );

}

/*-----------------------------------------------------------------------------------*/
/* STYLES AND SCRIPTS */
/*-----------------------------------------------------------------------------------*/ 

if ( ! function_exists( 'seanlite_includes' ) ) {

	function seanlite_includes() {

		$googleFontsArgs = array(
			'family' =>	str_replace('|', '%7C','Dr+Sugiyama|Roboto+Slab|PT+Serif:400,300,100,700'),
			'subset' =>	'latin,latin-ext'
		);

		wp_enqueue_style('google-fonts', add_query_arg ( $googleFontsArgs, "https://fonts.googleapis.com/css" ), array(), '1.0.0' );

		wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css', array(), '3.3.7' );
		wp_enqueue_style('font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.css', array(), '4.7.0' );
		wp_enqueue_style('genericons', get_template_directory_uri() . '/assets/css/genericons.css', array(), '4.0.5' );
		wp_enqueue_style('prettyPhoto', get_template_directory_uri() . '/assets/css/prettyPhoto.css', array(), '3.1.6' );
		wp_enqueue_style('swipebox.css', get_template_directory_uri() . '/assets/css/swipebox.css', array(), '1.3.0' );

		wp_enqueue_style('sean-lite-style', get_stylesheet_uri(), array() );

		if ( get_theme_mod('wip_skin') ) :
		
			wp_enqueue_style(
				'sean-lite' . get_theme_mod('wip_skin'), 
				get_template_directory_uri() . '/assets/skins/' . get_theme_mod('wip_skin') . '.css'
			); 
		
		endif;

		if ( is_singular() ) wp_enqueue_script( 'comment-reply' );
		
		wp_enqueue_script( 'jquery-easing', get_template_directory_uri() . '/assets/js/jquery.easing.js' , array('jquery'), '1.3', TRUE ); 
		wp_enqueue_script( 'infinitescroll', get_template_directory_uri() . '/assets/js/infinitescroll.js' , array('jquery'), '2.0.2', TRUE ); 
		wp_enqueue_script( 'jquery.scrollTo', get_template_directory_uri() . '/assets/js/jquery.scrollTo.js' , array('jquery'), '2.1.2', TRUE ); 
		wp_enqueue_script( 'modernizr', get_template_directory_uri() . '/assets/js/modernizr.js' , array('jquery'), '2.8.3', TRUE ); 
		wp_enqueue_script( 'prettyPhoto', get_template_directory_uri() . '/assets/js/prettyPhoto.js' , array('jquery'), '3.1.4', TRUE ); 
		wp_enqueue_script( 'swipebox', get_template_directory_uri() . '/assets/js/swipebox.js' , array('jquery'), '1.4.4', TRUE ); 
		wp_enqueue_script( 'tinynav', get_template_directory_uri() . '/assets/js/tinynav.js' , array('jquery'), '1.2', TRUE ); 
		wp_enqueue_script( 'sean-lite-template', get_template_directory_uri() . '/assets/js/template.js' , array('jquery'), '1.0.0', TRUE ); 
		wp_enqueue_script( 'sean-lite-navigation', get_template_directory_uri() . '/assets/js/navigation.js' , array('jquery'), '1.2', TRUE ); 

		wp_localize_script( 'sean-lite-template', 'seanLiteMobileMenu', array(
			'selectItem'   => __( 'Select an item', 'sean-lite' ),
		));

		wp_localize_script( 'sean-lite-navigation', 'accessibleNavigationScreenReaderText', array(
			'expandMain'   => __( 'Open the main menu', 'sean-lite' ),
			'collapseMain' => __( 'Close the main menu', 'sean-lite' ),
			'expandChild'   => __( 'expand submenu', 'sean-lite' ),
			'collapseChild' => __( 'collapse submenu', 'sean-lite' ),
		));

		wp_enqueue_script('html5shiv', get_template_directory_uri().'/assets/scripts/html5shiv.js', FALSE, '3.7.3');
		wp_script_add_data('html5shiv', 'conditional', 'IE 8' );
		wp_enqueue_script('selectivizr', get_template_directory_uri().'/assets/scripts/selectivizr.js', FALSE, '1.0.3b');
		wp_script_add_data('selectivizr', 'conditional', 'IE 8' );

	}
	
	add_action( 'wp_enqueue_scripts', 'seanlite_includes' );

}

/*-----------------------------------------------------------------------------------*/
/* THEME SETUP */
/*-----------------------------------------------------------------------------------*/   

if ( ! function_exists( 'seanlite_setup' ) ) {

	function seanlite_setup() {

		global $content_width;

		add_theme_support( 'post-formats', array( 'aside','gallery','quote','video','audio','link','status','chat','image' ) );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'title-tag' );
		
		add_image_size( 'blog', 940,seanlite_get_thumbs('blog'), TRUE ); 
		add_image_size( 'portfolio', 940,seanlite_get_thumbs('portfolio'), TRUE ); 
		
		add_image_size( 'large', 449,304, TRUE ); 
		add_image_size( 'medium', 290,220, TRUE ); 
		add_image_size( 'small', 211,150, TRUE ); 
	
		register_nav_menu( 'main-menu', 'Main menu' );
	
		load_theme_textdomain('sean-lite', get_template_directory() . '/languages');
	
		if ( ! isset( $content_width ) )
			$content_width = seanlite_setting('wip_screen3');
	
		add_theme_support( 'custom-background', array(
			'default-color' => 'f3f3f3',
		) );

		require_once( trailingslashit( get_template_directory() ) . '/core/includes/class-customize.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/includes/class-metaboxes.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/includes/class-notice.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/includes/class-plugin-activation.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/includes/class-welcome-page.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/admin/customize/customize.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/templates/after-content.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/templates/bottom_sidebar.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/templates/footer_sidebar.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/templates/header_sidebar.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/templates/media.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/templates/overlay.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/templates/post-formats.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/templates/social_buttons.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/templates/title.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/scripts/infinitescroll.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/functions/function-required-plugins.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/functions/function-style.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/functions/function-widgets.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/metaboxes/page.php' );
		require_once( trailingslashit( get_template_directory() ) . '/core/metaboxes/post.php' );
	
	}
	
	add_action( 'after_setup_theme', 'seanlite_setup' );

}

?>